/*
* ============================================================================
*  Name        : mvideocontrol.h
*  Part of     : mccexample / mccexapp
*  Description : MVideoControl class declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef M_MVIDEOCONTROL_H
#define M_MVIDEOCONTROL_H

#include <e32std.h>

#include "tcontrolstate.h"

class MMccExEngineObserver;

// Constants for screen rotation to be used when updating screen properties
const TInt KScreenRotation0( 0 );
const TInt KScreenRotation90( 90 );
const TInt KScreenRotation180( 180 );
const TInt KScreenRotation270( 270 );

/**
 * Declares an abstract video control interface. Actual implementation(s) may
 * include multiple up- and/or downlink streams and combinations.
 */
class MVideoControl
    {
public:
    
    /**
     * Prepares this video control.
     * 
     * @leave KErrNotReady If the state change is not allowed. Standard
     *                     Symbian error codes are used in other cases.
     */
    virtual void PrepareVideoL() = 0;
    
    /**
     * Starts this video control.
     * 
     * @leave KErrNotReady If the state change is not allowed. Standard
     *                     Symbian error codes are used in other cases.
     */
    virtual void StartVideoL() = 0;
    
    /**
     * Pauses this video control.
     * 
     * @leave KErrNotReady If the state change is not allowed. Standard
     *                     Symbian error codes are used in other cases.
     */
    virtual void PauseVideoL() = 0;
    
    /**
     * Resumes this (paused) video control.
     * 
     * @leave KErrNotReady If the state change is not allowed. Standard
     *                     Symbian error codes are used in other cases.
     */
    virtual void ResumeVideoL() = 0;
    
    /**
     * Stops this video control.
     * 
     * @leave KErrNotReady If the state change is not allowed. Standard
     *                     Symbian error codes are used in other cases.
     */
    virtual void StopVideoL() = 0;
    
    /**
     * Releases all the resources reserved by this video control and deletes
     * this instance. After calling this function, the video control is out of
     * scope and MUST NOT be referenced anymore.
     */
    virtual void ReleaseVideoControl() = 0;
    
    /**
     * Returns the current state of this video control.
     * 
     * @return TControlState Current video control state.
     */
    virtual TControlState State() = 0;
    
    /**
     * Updates the video screen rectangle and window properties.
     * 
     * @param aRect New screen rectangle.
     * @param aWindowOrdinalPosition Window ordinal position.
     * @param aWindowOrdinalPriority Window ordinal priority.
     * @param aScreenRotation Rotation to be used for the video screen.
     */
    virtual void UpdateScreenRectL( const TRect& aRect,
            TInt aWindowOrdinalPosition,
            TInt aWindowOrdinalPriority,
            TInt aScreenRotation ) = 0;
    
    };

#endif  // M_MVIDEOCONTROL_H
