/*
* ============================================================================
*  Name        : tvideodeviceparameters.h
*  Part of     : mccexample / mccexengine
*  Description : TVideoDeviceParameters class definition
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef T_TVIDEODEVICEPARAMETERS_H
#define T_TVIDEODEVICEPARAMETERS_H

#include <e32cmn.h>

/**
 * Video device parameters class. Used in loopback video control creation.
 * 
 * This class simply encapsulates a number of screen and camera related
 * parameters.
 */
class TVideoDeviceParameters
    {
public:
    
    /**
     * Default constructor.
     */
    TVideoDeviceParameters() : iWindowOrdinalPosition( KErrNotFound ),
        iWindowOrdinalPriority( KErrNotFound ),
        iCameraIndex( KErrNotFound ),
        iScreenIndex( KErrNotFound )
        {   };
    
    /**
     * Parametrized constructor.
     */
    TVideoDeviceParameters( TInt aWinOrdinalPos, TInt aWinOrdinalPrio,
        TInt aCamIndex, TInt aScreenIndex ) : 
        iWindowOrdinalPosition( aWinOrdinalPos ),
        iWindowOrdinalPriority( aWinOrdinalPrio ),
        iCameraIndex( aCamIndex ),
        iScreenIndex( aScreenIndex )
        {   };
    
public:
    
    /**
     * Window ordinal position.
     */
    TInt iWindowOrdinalPosition;
    
    /**
     * Window ordinal priority.
     */
    TInt iWindowOrdinalPriority;
    
    /**
     * Camera index.
     */
    TInt iCameraIndex;
    
    /**
     * Screen index.
     */
    TInt iScreenIndex;
    
    };

#endif  // T_TVIDEODEVICEPARAMETERS_H
