/*
* ============================================================================
*  Name        : mccexappcodecsettings.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppCodecSettings declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPCODECSETTINGS_H
#define C_CMCCEXAPPCODECSETTINGS_H

#include <e32std.h>
#include "tcodecsettings.h"

/**
 * Class CMccExAppCodecSettings is used as the data model for the 
 * CMccExAppCodecSettingList class. This class should not be used in other
 * purposes.
 * 
 * @see CMccExAppCodecSettingList
 * @see CMccExAppCodecSettingView
 */
class CMccExAppCodecSettings : public CBase
    {
public:
    
// Constructors and destructor.
    
    /**
     * Two-phased constructor.
     * 
     * @return Pointer to a newly created object.
     */
    static CMccExAppCodecSettings* NewL();
    
    /**
     * Two-phased constructor. Leaves the created object into cleanup stack.
     * 
     * @return Pointer to a newly created object.
     */
    static CMccExAppCodecSettings* NewLC();
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppCodecSettings();
    
// New functions.
    
    /**
     * Accessor for the codec index.
     * 
     * @return TInt& Reference to the codec index.
     */
    TInt& Codec();
    
    /**
     * Accessor for the PTime of the codec.
     * 
     * @return TInt& Reference to the codec PTime.
     */
    TInt& PTime();
    
    /**
     * Accessor for the MaxPTime of the codec.
     * 
     * @return TInt& Reference to the codec MaxPTime.
     */
    TInt& MaxPTime();
    
    /**
     * Accessor for the VAD/CN enablation of the codec.
     * 
     * @return TBool& Reference to the codec VAD/CN enablation.
     */
    TBool& VadCn();
    
    /**
     * Accessor for the jitterbuffer size of the codec.
     * 
     * @return TInt& Reference to the codec jitterbuffer size.
     */
    TInt& JitterBufferSize();
    
    /**
     * Returns a reference to the codec settings.
     * Ownership is not transferred.
     * 
     * @return RArray<TCodecSettings>& Reference to the codec settings array.
     */
    const RArray<TCodecSettings>& CodecSettings();
    
    /**
     * Saves the internal values to the most preferred code.
     */
    void SaveInternalValues();
    
    /**
     * Updates the codec setting values based on iCodec selection and
     * re-arranges the settings array.
     */
    void UpdateSettingsFromIndex();
    
    /**
     * Sets the current codec index.
     * 
     * @param aValue New codec index.
     */
    void SetCodec( const TInt& aValue );
    
    /**
     * Sets the PTime for this codec.
     * 
     * @param aValue New PTime value.
     */
    void SetPTime( const TInt& aValue );
    
    /**
     * Sets the MaxPTime for this codec.
     * 
     * @param aValue New MaxPTime value.
     */
    void SetMaxPTime( const TInt& aValue );
    
    /**
     * Sets the VAD/CN for this codec.
     * 
     * @param aValue New VAD/CN value.
     */
    void SetVadCn( const TBool& aValue );
    
    /**
     * Sets the jitterbuffer size for this codec.
     * 
     * @param aValue New jitterbuffer size value.
     */
    void SetJitterBufferSize( const TInt& aValue );
    
    /**
     * Sets the codec settings. Function makes a copy of the given parameter
     * array.
     * 
     * @param aSettings New codec settings array.
     */
     void SetCodecSettingsL( const RArray<TCodecSettings>& aSettings );
    
private:
    
    /**
     * C++ default constructor.
     */
    CMccExAppCodecSettings();

private:    // Data
    
    /**
     * Index of the codec.
     */
    TInt iCodec;
    
    /**
     * Codec PTime.
     */
    TInt iPTime;
    
    /**
     * Codec Max PTime.
     */
    TInt iMaxPTime;
    
    /**
     * VAD/CN enabled.
     */
    TBool iVadCn;
    
    /**
     * Jitterbuffer size.
     */
    TInt iJitterBufferSize;
    
    /**
     * Actual codec settings array.
     */
    RArray<TCodecSettings> iSettings;
    
    };

#endif // C_CMCCEXAPPCODECSETTINGS_H
