/*
* ============================================================================
*  Name        : mccexappnwsettings.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppNwSettings declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPNWSETTINGS_H
#define C_CMCCEXAPPNWSETTINGS_H

#include <e32std.h>
#include <in_sock.h>

/**
 * Class CMccExAppNwSettings is used as the data model for the 
 * CMccExAppNwSettingsList class. This class should not be used in other
 * purposes.
 * 
 * @see CMccExAppNwSettingsList
 * @see CMccExAppNwSettingsView
 */
class CMccExAppNwSettings : public CBase
    {
public:
// Constructors and destructor.
    
    /**
     * Two phased constructor.
     * 
     * @return New CMccExAppNwSettings object.
     */
    static CMccExAppNwSettings* NewL();
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppNwSettings();
    
// New functions.
    
    /**
     * Accessor for remote address.
     * 
     * @return Reference to the remote address.
     */
    TInetAddr& RemoteAddress();
    
    /**
     * Accessor for the RTP port.
     * 
     * @return Reference to the RTP port.
     */
    TInt& RtpPort();
    
    /**
     * Accessor for the RTCP status.
     * 
     * @return Reference to the RTCP status.
     */
    TBool& RtcpStatus();
    
    /**
     * Accessor for the media QoS.
     * 
     * @return Reference to the media QoS.
     */
    TInt& MediaQoS();
    
    /**
     * Sets the remote address.
     * 
     * @param aAddress New remote address.
     */
    void SetRemoteAddress( const TInetAddr& aAddress );
    
    /**
     * Sets the RTP port.
     * 
     * @param aPort New RTP port.
     */
    void SetRtpPort( const TInt& aPort );
    
    /**
     * Sets the RTCP status.
     * 
     * @param aRtcpStatus New RTCP status.
     */
    void SetRtcpStatus( const TBool& aRtcpStatus );
    
    /**
     * Sets the media QoS.
     * 
     * @param aMediaQoS New media QoS value.
     */
    void SetMediaQoS( const TInt& aMediaQoS );
    
private:
    
    /**
     * C++ default constructor.
     */
    CMccExAppNwSettings();
    
private:    // Data
    
    /**
     * Remote address.
     */
    TInetAddr iRemoteAddress;
    
    /**
     * RTP port.
     */
    TInt iRtpPort;
    
    /**
     * RTCP usage status.
     */
    TBool iRtcpStatus;
    
    /**
     * Media QoS value.
     */
    TInt iMediaQoS;
    
    };

#endif // C_CMCCEXAPPNWSETTINGS_H
