/*
* ============================================================================
*  Name        : mccexappcodecsettings.cpp
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppCodecSettings class implementation
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/


#include <e32base.h>

#include "mccexappcodecsettings.h"
#include "mccexpanic.pan"


// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::NewL
// ---------------------------------------------------------------------------
//
CMccExAppCodecSettings* CMccExAppCodecSettings::NewL()
    {
    CMccExAppCodecSettings* self = CMccExAppCodecSettings::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::NewLC
// ---------------------------------------------------------------------------
//
CMccExAppCodecSettings* CMccExAppCodecSettings::NewLC()
    {
    CMccExAppCodecSettings* self = new ( ELeave ) CMccExAppCodecSettings();
    CleanupStack::PushL( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::~CMccExAppCodecSettings
// ---------------------------------------------------------------------------
//
CMccExAppCodecSettings::~CMccExAppCodecSettings()
    {
    iSettings.Close();
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::Codec
// ---------------------------------------------------------------------------
//
TInt& CMccExAppCodecSettings::Codec()
    {
    return iCodec;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::PTime
// ---------------------------------------------------------------------------
//
TInt& CMccExAppCodecSettings::PTime()
    {
    return iPTime;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::MaxPTime
// ---------------------------------------------------------------------------
//
TInt& CMccExAppCodecSettings::MaxPTime()
    {
    return iMaxPTime;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::VadCn
// ---------------------------------------------------------------------------
//
TBool& CMccExAppCodecSettings::VadCn()
    {
    return iVadCn;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::JitterBufferSize
// ---------------------------------------------------------------------------
//
TInt& CMccExAppCodecSettings::JitterBufferSize()
    {
    return iJitterBufferSize;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::CodecSettings
// ---------------------------------------------------------------------------
//
const RArray<TCodecSettings>& CMccExAppCodecSettings::CodecSettings()
    {
    return iSettings;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::CodecSettings
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SaveInternalValues()
    {
    // Update the priority codec from internal values. Note as we are using a
    // temporary TCodecSettings, be sure it refers to the one in the array!
    TCodecSettings& setting = iSettings[iCodec];
    setting.iPTime = iPTime;
    setting.iMaxPTime = iMaxPTime;
    setting.iVadCn = iVadCn;
    setting.iJitterBufferSize = iJitterBufferSize;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::UpdateSettingsFromIndex
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::UpdateSettingsFromIndex()
    {
    // Check that we are on proper range comparing to the array.
    __ASSERT_ALWAYS( iCodec < iSettings.Count(),
        MccExPanic( EMccExOutOfBounds ) );
    
    // Move the selected codec as the first codec.
    TCodecSettings selected = iSettings[iCodec];
    iSettings.Remove( iCodec );
    iSettings.Insert( selected, 0 );
    
    // Update the internal values.
    iCodec = 0;
    iPTime = iSettings[ iCodec ].iPTime;
    iMaxPTime = iSettings[ iCodec ].iMaxPTime;
    iVadCn = iSettings[ iCodec ].iVadCn;
    iJitterBufferSize = iSettings[ iCodec ].iJitterBufferSize;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::SetCodec
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetCodec( const TInt& aValue )
    {
    iCodec = aValue;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::SetPTime
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetPTime( const TInt& aValue )
    {
    iPTime = aValue;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::SetJitterBufferSize
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetJitterBufferSize( const TInt& aValue )
    {
    iJitterBufferSize = aValue;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::SetMaxPTime
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetMaxPTime( const TInt& aValue )
    {
    iMaxPTime = aValue;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::SetVadCn
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetVadCn( const TBool& aValue )
    {
    iVadCn = aValue;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::CodecSettings
// ---------------------------------------------------------------------------
//
void CMccExAppCodecSettings::SetCodecSettingsL(
    const RArray<TCodecSettings>& aSettings )
    {
    const TInt codecAmt( aSettings.Count() );
    // Assert that we have always at least one codec setting.
    __ASSERT_ALWAYS( codecAmt, User::Leave( KErrArgument ) );
    iSettings.Reset();
    for( TInt k = 0; k < codecAmt; k++ )
        {
        iSettings.AppendL( aSettings[ k ] );
        }
    
    // Shut-up CodeScanner - and do it in debug builds. In real world AppendL
    // fails and leave occurs and this is never reached.
    __ASSERT_DEBUG( iSettings.Count(), MccExPanic( EMccExOutOfBounds ) );
    
    iCodec = 0;
    iPTime = iSettings[ iCodec ].iPTime;
    iMaxPTime = iSettings[ iCodec ].iMaxPTime;
    iVadCn = iSettings[ iCodec ].iVadCn;
    iJitterBufferSize = iSettings[ iCodec ].iJitterBufferSize;
    }


// ---------------------------------------------------------------------------
// CMccExAppCodecSettings::CMccExAppCodecSettings
// ---------------------------------------------------------------------------
//
CMccExAppCodecSettings::CMccExAppCodecSettings()
    {
    }
