/*
* ============================================================================
*  Name        : audiostreambase.h
*  Part of     : mccexample / mccexengine
*  Description : CAudioStreamBase declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CAUDIOSTREAMBASE_H
#define C_CAUDIOSTREAMBASE_H

#include <e32base.h>

#include "streambase.h"

class CMccInterface;
class CMccCodecInformation;
class CStreamStateMachine;

// Following audio priority and preference values have been copied from
// audioproxy server developed by Forum Nokia. These values are needed for
// full-duplex audio streaming.

// Audio priority shared by the streams.
const TInt KExampleAudioPriority = 100;
// Downlink audio preference for VoIP like applications
const TUint KExampleDownlinkPreference = 0x05210001;
// Uplink audio preference for VoIP like applications
const TUint KExampleUplinkPreference = 0x05220001;
/**
 * CAudioStreamBase provides a base class for up- and downlink audio streams.
 */
NONSHARABLE_CLASS( CAudioStreamBase ) : public CStreamBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CAudioStreamBase();
    
protected:
    
    /**
     * Constructor for performing 1st stage construction
     * 
     * @param aStateMachine Statemachine for the stream.
     * @param aMcc MCC instance for the stream.
     * @param aSession ID of the session in which this stream will belong.
     * @param aLink ID of the link in which this stream will belong.
     */
    CAudioStreamBase( CStreamStateMachine& aStateMachine,
            CMccInterface& aMcc, TUint32 aSession, TUint32 aLink );
    
    /**
     * Symbian default constructor for performing 2nd stage construction.
     * 
     * @see mmccinterfacedef.h For different stream types.
     * @see streambase.h For further information on possible leave codes.
     * @leave KErrArgument If the specified aType is other than 
     *        KMccAudioDownlinkStream or KMccAudioUplinkStream.
     * @param aCodec Codec used in this stream.
     * @param aType Type of this stream.
     */
    void ConstructL( CMccCodecInformation& aCodec, TInt aType );
    
    /**
     * Sets codec audio priority and preference values for this stream.
     * Note that these values are not flushed to MCC or lower level audio
     * software until CStreamBase::CreateStreamL is called.
     * 
     * @see CStreamBase::CreateStreamL()
     * @param aPriority Audio priority value.
     * @param aPreference Audio preference value.
     */
    void SetCodecPriorityAndPreference( TInt aPriority, TInt aPreference );
    
    };

#endif  // C_CAUDIOSTREAMBASE_H
