/*
* ============================================================================
*  Name        : downlinkvideostream.h
*  Part of     : mccexample / mccexengine
*  Description : CDownlinkVideoStream declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CDOWNLINKVIDEOSTREAM_H
#define C_CDOWNLINKVIDEOSTREAM_H

#include <e32base.h>

#include "videostreambase.h"

class CMccInterface;
class CMccCodecInformation;
class CStreamStateMachine;

/**
 * CDownlinkVideoStream provides an implementation of downlink direction video
 * stream. In short this class can be used to create and control a video
 * stream from IP network to device video output (device screen).
 */
NONSHARABLE_CLASS( CDownlinkVideoStream ) : public CVideoStreamBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CDownlinkVideoStream();

    /**
     * Two-phased constructor.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for video.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aRect Initial video screen rectangle.
     * @param aWindowOrdinalPos Window ordinal position.
     * @param aWindowOrdinalPrio Window ordinal priority.
     * @param aScreenIndex Screen index.
     */
    static CDownlinkVideoStream* NewL( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc,
            TUint32 aSession, TUint32 aLink,
            const TRect& aRect,
            TInt aWindowOrdinalPos,
            TInt aWindowOrdinalPrio,
            TInt aScreenIndex );

    /**
     * Two-phased constructor. Leaves the created instance into the cleanup
     * stack.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for video.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aRect Initial video screen rectangle.
     * @param aWindowOrdinalPos Window ordinal position.
     * @param aWindowOrdinalPrio Window ordinal priority.
     * @param aScreenIndex Screen index.
     */
    static CDownlinkVideoStream* NewLC( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc,
            TUint32 aSession, TUint32 aLink,
            const TRect& aRect,
            TInt aWindowOrdinalPos,
            TInt aWindowOrdinalPrio,
            TInt aScreenIndex );
    
    /**
     * Updates the screen rectangle.
     * 
     * @param aRect Screen rectangle.
     * @param aWindowOrdinalPosition Window position.
     * @param aWindowOrdinalPriority Window priority.
     * @param aScreenRotation Rotation for the video screen.
     */
    void UpdateScreenRectL( const TRect& aRect,
            TInt aWindowOrdinalPosition,
            TInt aWindowOrdinalPriority,
            TInt aScreenRotation );
    
protected:
    
// From CStreamBase
    
    /**
     * From CStreamBase.
     * Final stream creation.
     * 
     * @see CStreamBase
     */
    void CreateStreamL();
    
private:
    
    /**
     * Constructor for performing 1st stage construction.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aRect Initial video screen rectangle.
     * @param aWindowOrdinalPos Window ordinal position.
     * @param aWindowOrdinalPrio Window ordinal priority.
     * @param aScreenIndex Screen index.
     */
    CDownlinkVideoStream( CStreamStateMachine& aStateMachine,
            CMccInterface& aMcc, TUint32 aSession, TUint32 aLink,
            const TRect& aRect,
            TInt aWindowOrdinalPos,
            TInt aWindowOrdinalPrio,
            TInt aScreenIndex );
    
private:    // Data
    
    /**
     * Video screen rectangle.
     */
    TRect iRect;
    
    /**
     * Window ordinal position.
     */
    TInt iWindowOrdinalPosition;
    
    /**
     * Window ordinal priority.
     */
    TInt iWindowOrdinalPriority;
    
    /**
     * Current screen rotation.
     */
    TInt iScreenRotation;
    
    /**
     * Screen index.
     */
    TInt iScreenIndex;
    
    };

#endif  // C_CDOWNLINKVIDEOSTREAM_H
