/*
* ============================================================================
*  Name        : streamstatebase.h
*  Part of     : mccexample / mccexengine
*  Description : CStreamStateBase declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CSTREAMSTATEBASE_H
#define C_CSTREAMSTATEBASE_H

#include <e32base.h>
#include "tcontrolstate.h"

class CStreamBase;
class TMccEvent;

/**
 * CStreamStateBase functions as a base class for different stream states.
 */
NONSHARABLE_CLASS( CStreamStateBase ) : public CBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CStreamStateBase();
    
    /**
     * Called when this state is entered. Function calls DoEnterStateL which
     * deriving classes need to implement.
     * 
     * @leave KErrNotSupported If the state transition is not acceptable.
     *                         Standard Symbian error code otherwise.
     * @param aStream Stream for which the state change is done.
     * @param aPrevState Previous state of the stream.
     */
    void EnterStateL( CStreamBase& aStream,
            const CStreamStateBase& aPrevState );
    
    /**
     * Handles a MCC event associated for this state. Every state must
     * implement this function in order to handle the events it is interested
     * in.
     * 
     * @param aEvent The event to be handled.
     * @param aStream The stream associated for this event.
     */
    virtual void HandleMccEvent( const TMccEvent& aEvent,
            CStreamBase& aStream );
    
    /**
     * Returns the TControlState of this state. This function can be used to
     * differentiate between states.
     * 
     * @return TControlState Associated control state for this state object.
     */
    virtual TControlState ControlState() const = 0;
    
protected:
    
    /**
     * Constructor for performing 1st stage construction.
     */
    CStreamStateBase();
    
    /**
     * Called from EnterStateL function.
     * 
     * @param aStream Stream for which the statechange is done.
     * @param aPrevState Previous state of the stream.
     */
    virtual void DoEnterStateL( CStreamBase& aStream,
            const CStreamStateBase& aPrevState ) = 0;
    
    };

#endif  // C_CSTREAMSTATEBASE_H
