/*
* ============================================================================
*  Name        : uplinkaudiostream.h
*  Part of     : mccexample / mccexengine
*  Description : CUplinkAudioStream declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CUPLINKAUDIOSTREAM_H
#define C_CUPLINKAUDIOSTREAM_H

#include <e32base.h>

#include "audiostreambase.h"

class CMccInterface;
class CMccCodecInformation;
class CStreamStateMachine;

/**
 * CUplinkAudioStream provides an implementation of uplink direction audio
 * stream. In short this class can be used to create and control an audio
 * stream from audio input device (i.e. mic) to IP network.
 */
NONSHARABLE_CLASS( CUplinkAudioStream ) : public CAudioStreamBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CUplinkAudioStream();

    /**
     * Two-phased constructor.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for audio.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     */
    static CUplinkAudioStream* NewL( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc, 
            TUint32 aSession, TUint32 aLink );

    /**
     * Two-phased constructor. Leaves the created instance into the cleanup
     * stack.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for audio.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     */
    static CUplinkAudioStream* NewLC( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc,
            TUint32 aSession, TUint32 aLink );
    
    /**
     * Enables/Disables the mic mute using underlying mic gain functionality.
     * 
     * @see maudiocontrol.h
     * @param aMuteState Mute state (enable/disable).
     */
    void SetMuteStateL( TBool aMuteState );
    
protected:
    
// From CStreamBase
    
    /**
     * From CStreamBase.
     * Finalizes the stream creation.
     * 
     * @see CStreamBase
     */
    void CreateStreamL();
    
private:
    
    /**
     * Constructor for performing 1st stage construction.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     */
    CUplinkAudioStream( CStreamStateMachine& aStateMachine,
            CMccInterface& aMcc, TUint32 aSession, TUint32 aLink );

    };

#endif  // C_CUPLINKAUDIOSTREAM_H
