/*
* ============================================================================
*  Name        : downlinkvideostream.cpp
*  Part of     : mccexample / mccexengine
*  Description : CDownlinkVideoStream class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccinterface.h>
#include <mmccinterfacedef.h>

#include "mvideocontrol.h"
#include "downlinkvideostream.h"

// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CDownlinkVideoStream::CDownlinkVideoStream
// ---------------------------------------------------------------------------
//
CDownlinkVideoStream::CDownlinkVideoStream(
    CStreamStateMachine& aStateMachine,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink,
    const TRect& aRect,
    TInt aWindowOrdinalPos,
    TInt aWindowOrdinalPrio,
    TInt aScreenIndex ) : 
    CVideoStreamBase( aStateMachine, aMcc, aSession, aLink ),
    iRect( aRect ),
    iWindowOrdinalPosition( aWindowOrdinalPos ),
    iWindowOrdinalPriority( aWindowOrdinalPrio ),
    iScreenIndex( aScreenIndex )
    {
    }


// ---------------------------------------------------------------------------
// CDownlinkVideoStream::~CDownlinkVideoStream
// ---------------------------------------------------------------------------
//
CDownlinkVideoStream::~CDownlinkVideoStream()
    {
    }


// ---------------------------------------------------------------------------
// CDownlinkVideoStream::NewLC
// ---------------------------------------------------------------------------
//
CDownlinkVideoStream* CDownlinkVideoStream::NewLC(
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink,
    const TRect& aRect,
    TInt aWindowOrdinalPos,
    TInt aWindowOrdinalPrio,
    TInt aScreenIndex )
    {
    CDownlinkVideoStream* self = new ( ELeave ) CDownlinkVideoStream( 
            aStateMachine, aMcc, aSession, aLink, aRect,
            aWindowOrdinalPos, aWindowOrdinalPrio, aScreenIndex );
    CleanupStack::PushL( self );
    self->ConstructL( aCodec, KMccVideoDownlinkStream );
    return self;
    }


// ---------------------------------------------------------------------------
// CDownlinkVideoStream::NewL
// ---------------------------------------------------------------------------
//
CDownlinkVideoStream* CDownlinkVideoStream::NewL(
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink,
    const TRect& aRect,
    TInt aWindowOrdinalPos,
    TInt aWindowOrdinalPrio,
    TInt aScreenIndex )
    {
    CDownlinkVideoStream* self = CDownlinkVideoStream::NewLC( aStateMachine, 
            aCodec, aMcc, aSession, aLink, aRect,
            aWindowOrdinalPos, aWindowOrdinalPrio, aScreenIndex );
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CDownlinkVideoStream::UpdateScreenRectL
// ---------------------------------------------------------------------------
//
void CDownlinkVideoStream::UpdateScreenRectL( const TRect& aRect,
    TInt aWindowOrdinalPosition,
    TInt aWindowOrdinalPriority,
    TInt aScreenRotation )
    {
    // Disable viewfinder (and try to do it always). If viewfinder is needed
    // then enable it by passing TMccVideoSinkSetting package with the
    // KMccCamLocalVideo parameter.
    MccInterface().SetParameter( SessionId(), LinkId(),
            StreamId(), SinkEndpointId(), KMccCamLocalVideo, KNullDesC8 );
    
    TMccVideoSinkSetting settings;
    
    TMccVideoRotation rotation( EMccNone );
    if ( KScreenRotation90 == aScreenRotation )
        {
        rotation = EMccClockwise90Degree;
        }
    else if ( KScreenRotation180 == aScreenRotation )
        {
        rotation = EMccClockwise180Degree;
        }
    else if ( KScreenRotation270 == aScreenRotation )
        {
        rotation = EMccClockwise270Degree;
        }
    
    settings.iAudioPayloadType = KAudioPayloadType;
    settings.iVideoPayloadType = KVideoPayloadType;
    settings.iDeviceIndex = iScreenIndex;
    settings.iWindowOrdinalPosition = aWindowOrdinalPosition;
    settings.iWindowOrdinalPriority = aWindowOrdinalPriority;
    settings.iLocation = aRect.iTl;
    settings.iSize = aRect.Size();
    settings.iRotation = rotation;
    
    TMccVideoSinkSettingBuf buffer( settings );
    
    User::LeaveIfError( MccInterface().SetParameter( SessionId(),
            LinkId(), StreamId(), SinkEndpointId(),
            KMccDisplayLocalVideo, buffer ) );
    
    iRect = aRect;
    iWindowOrdinalPosition = aWindowOrdinalPosition;
    iWindowOrdinalPriority = aWindowOrdinalPriority;
    iScreenRotation = aScreenRotation;
    }


// ---------------------------------------------------------------------------
// CDownlinkVideoStream::CreateStreamL
// ---------------------------------------------------------------------------
//
void CDownlinkVideoStream::CreateStreamL()
    {
    TMccVideoSinkSetting settings;
    settings.iAudioPayloadType = KAudioPayloadType;
    settings.iVideoPayloadType = KVideoPayloadType;
    settings.iDeviceIndex = iScreenIndex;
    settings.iWindowOrdinalPosition = iWindowOrdinalPosition;
    settings.iWindowOrdinalPriority = iWindowOrdinalPriority;
    settings.iRotation = EMccNone;
    
    settings.iLocation = iRect.iTl;
    settings.iSize = iRect.Size();
    
    TMccVideoSinkSettingBuf buffer( settings );
    
    AddSinkL( KUidMccVideoSink, buffer );
    AddSourceL( KUidMccRtpSource, KNullDesC8 );
    
    CStreamBase::CreateStreamL();
    }
